# cidipi

Low-level client for interacting with Chrome Devtools Protocol (CDP) for Python.

> [!WARNING]
> This library is in alpha. Use it at your own risk.

## Installation

```bash
pip install --pre cidipi
```

## Usage

See the [examples/](https://github.com/aprilahijriyan/cidipi/tree/main/examples) directory to get started.
